# src/guardianhub/__init__.py
from ._version import __version__  # version exported for users

from .logging import get_logger,setup_logging

# Expose public modules (minimal)
__all__ = ["__version__","get_logger","setup_logging"]